@@ -4,7 +4,7 @@ from tensorflow.keras.layers import Input, Embedding, dot, Reshape, Activation,
 from tensorflow.keras.regularizers import l1
 from tensorflow.keras.optimizers import Adam
 from sklearn.metrics.pairwise import cosine_similarity
-from .eval_measure import fmeasure
+from topicmodels.eval_measure import fmeasure
 # import tensorflow as tf
 
 from tensorflow.keras.layers import Input,LSTM,Embedding,Dense,Concatenate,TimeDistributed,Bidirectional
